@@ -955,12 +955,360 @@ var SAO_XAU_TEN = new Array(
         );
 
 var SAO_XAU_MATRIX= new Array(
-        new Array(),
-                new Array(),
-                new Array(),
-                new Array(),
-                new Array(),
-                new Array(),
+        new Array(
+            "Tỵ",
+            "Dậu",
+            "Tý",
+            "Tỵ",
+            "Ngọ",
+            "Tỵ",
+            "Thân",
+            "Hợi",
+            "Hợi",
+            "Dần",
+            "Thìn",
+            "Mùi",
+            "Tuất",
+            "Tỵ Dậu Sửu",
+            "Thìn",
+            "Sửu",
+            "Sửu",
+            "Tỵ",
+            "Tuất",
+            "Sửu",
+            "Ngọ",
+            "Dần",
+            "Dậu",
+            "Tỵ",
+            "Tý",
+            "Ngọ",
+            "Tỵ",
+            "Hợi",
+            "Dần",
+            "Thìn",
+            "Giáp",
+            "Canh",
+            "Mão",
+            "Ngọ",
+            "Dậu",
+            "Hợi",
+            "Dần",
+            "Tuất",
+            "Thìn",
+            "Tỵ",
+            "Tỵ",
+            "Ngọ",
+            "Mão",
+            "Quý Mão",
+            "Ất Mão",
+            "Tý",
+            "Thìn",
+            "Thìn",
+            "Tỵ",
+            "Ất Mùi",
+            "Hợi",
+            "Dậu",
+            "Sửu",
+            "Thìn",
+            "Canh Tuất",
+            "Giáp Dần",
+            "Tuất"
+            ),//1
+                new Array(
+            "Tý",
+            "Ngọ",
+            "Mão",
+            "Dậu",
+            "Mùi",
+            "Ngọ",
+            "Dậu Tuất",
+            "Thân",
+            "Tý",
+            "Mão",
+            "Tỵ",
+            "Tuất",
+            "Thìn",
+            "Tỵ Dậu Sửu",
+            "Dậu",
+            "Tý",
+            "Mùi",
+            "Thìn",
+            "Dậu",
+            "Tuất",
+            "Dần",
+            "Ngọ",
+            "Mùi",
+            "Mão",
+            "Dậu",
+            "Dần",
+            "Tý",
+            "Ngọ",
+            "Tỵ",
+            "Sửu",
+            "Ất",
+            "Tân",
+            "Tỵ",
+            "Thân",
+            "Hợi",
+            "Tỵ",
+            "Hợi",
+            "Hợi",
+            "Tỵ",
+            "Tý",
+            "Tý",
+            "Tý",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Dậu",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Tỵ",
+            "Tân Dậu",
+            "Ất Mão",
+            "Tuất"
+            ),//2
+                new Array(
+            "Mùi",
+            "Mão",
+            "Ngọ",
+            "Sửu",
+            "Thân",
+            "Mùi",
+            "Tuất",
+            "Tỵ",
+            "Sửu",
+            "Thìn",
+            "Ngọ",
+            "Thìn",
+            "Hợi",
+            "Tỵ Dậu Sửu",
+            "Dần",
+            "Hợi",
+            "Dần",
+            "Mão",
+            "Thân",
+            "Mùi",
+            "Tý",
+            "Tuất",
+            "Tỵ",
+            "Sửu",
+            "Ngọ",
+            "Thìn",
+            "Sửu",
+            "Sửu",
+            "Thân",
+            "Tuất",
+            "Kỷ",
+            "Kỷ",
+            "Mùi",
+            "Tuất",
+            "Tỵ",
+            "Mão",
+            "Tỵ",
+            "Tý",
+            "Ngọ",
+            "Mùi",
+            "Thìn",
+            "Mùi",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Sửu",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Tý",
+            "Canh Thân",
+            "Giáp Thìn",
+            "Tuất"
+            ),//3
+                new Array(
+            "Dần",
+            "Tý",
+            "Dậu",
+            "Tỵ",
+            "Dậu",
+            "Thân",
+            "Hợi",
+            "Dần",
+            "Dần",
+            "Tỵ",
+            "Mùi",
+            "Dần",
+            "Tỵ",
+            "Thân Tý Thìn",
+            "Mùi",
+            "Tuất",
+            "Thân",
+            "Dần",
+            "Mùi",
+            "Thìn",
+            "Ngọ",
+            "Tỵ",
+            "Mão",
+            "Hợi",
+            "Mão",
+            "Dậu",
+            "Dần",
+            "Thân",
+            "Hợi",
+            "Mùi",
+            "Bính",
+            "Nhâm",
+            "Dậu",
+            "Tý",
+            "Mão",
+            "Sửu",
+            "Thân",
+            "Sửu",
+            "Mùi",
+            "Mão",
+            "Thân",
+            "Sửu",
+            "Ngọ",
+            "Bính Ngọ",
+            "Bính Ngọ",
+            "Mão",
+            "Mùi",
+            "Mùi",
+            "Thân",
+            "Bính Tuất",
+            "Dần",
+            "Dần,Ngọ",
+            "Thìn",
+            "Tuất",
+            "Đinh Mùi",
+            "Đinh Tỵ",
+            "Tuất"
+            ),//4
+                new Array(
+            "Dậu",
+            "Dậu",
+            "Tý",
+            "Dậu",
+            "Tuất",
+            "Dậu",
+            "Tý Sửu",
+            "Hợi",
+            "Mão",
+            "Ngọ",
+            "Thân",
+            "Ngọ",
+            "Tý",
+            "Thân Tý Thìn",
+            "Tý",
+            "Dậu",
+            "Mão",
+            "Sửu",
+            "Ngọ",
+            "Sửu",
+            "Dần",
+            "Dậu",
+            "Sửu",
+            "Dậu",
+            "Tý",
+            "Mão",
+            "Mão",
+            "Mão",
+            "Mão",
+            "Mão",
+            "Đinh",
+            "Quý",
+            "Hợi",
+            "Dần",
+            "Sửu",
+            "Mùi",
+            "Dần",
+            "Dần",
+            "Thân",
+            "Thân",
+            "Ngọ",
+            "Thân",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Tý",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Hợi",
+            "Bính Ngọ",
+            "Bính Ngọ",
+            "Tuất"
+            ),//5
+                new Array(
+            "Thìn",
+            "Ngọ",
+            "Mão",
+            "Sửu",
+            "Hợi",
+            "Tuất",
+            "Sửu",
+            "Thân",
+            "Thìn",
+            "Mùi",
+            "Dậu",
+            "Tý",
+            "Ngọ",
+            "Thân Tý Thìn",
+            "Tỵ",
+            "Thân",
+            "Dậu",
+            "Tý",
+            "Tỵ",
+            "Tuất",
+            "Tý",
+            "Sửu",
+            "Hợi",
+            "Mùi",
+            "Dậu",
+            "Thân",
+            "Tuất",
+            "Tuất",
+            "Ngọ",
+            "Tý",
+            "Kỷ",
+            "Mậu",
+            "Sửu",
+            "Thìn",
+            "Mùi",
+            "Dậu",
+            "Hợi",
+            "Mão",
+            "Dậu",
+            "Tuất",
+            "Sửu",
+            "Dần",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Thìn",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Mùi",
+            "Đinh Tỵ",
+            "Đinh Mùi",
+            "Tuất"
+            ),//6
                 new Array(
             "Hợi",
             "Mão",
@@ -1020,11 +1368,301 @@ var SAO_XAU_MATRIX= new Array(
             "Canh Thân",
             "Tuất"
             ),//7
-                new Array(),
-                new Array(),
-                new Array(),
-                new Array(),
-                new Array()
+                new Array(
+            "Ngọ",
+            "Tý",
+            "Dậu",
+            "Dậu",
+            "Sửu",
+            "Tý",
+            "Mão Thìn",
+            "Dần",
+            "Ngọ",
+            "Dậu",
+            "Hợi",
+            "Thân",
+            "Mùi",
+            "Hợi Mão Mùi",
+            "Mão",
+            "Ngọ",
+            "Tuất",
+            "Tuất",
+            "Mão",
+            "Thìn",
+            "Dần",
+            "Tý",
+            "Mùi",
+            "Mão",
+            "Mão",
+            "Tỵ",
+            "Ngọ",
+            "Tý",
+            "Tý",
+            "Ngọ",
+            "Tân",
+            "Ất",
+            "Tỵ",
+            "Thân",
+            "Hợi",
+            "Tỵ",
+            "Thân",
+            "Tỵ",
+            "Hợi",
+            "Hợi",
+            "Dậu",
+            "Mão",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Mão",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Mão",
+            "Ất Mão",
+            "Tân Dậu",
+            "Tuất"
+            ),//8
+                new Array(
+            "Sửu",
+            "Dậu",
+            "Tý",
+            "Sửu",
+            "Dần",
+            "Sửu",
+            "Thìn",
+            "Hợi",
+            "Mùi",
+            "Tuất",
+            "Tý",
+            "Tỵ",
+            "Dần",
+            "Hợi Mão Mùi",
+            "Thân",
+            "Tỵ",
+            "Tỵ",
+            "Dậu",
+            "Dần",
+            "Sửu",
+            "Tý",
+            "Thìn",
+            "Tỵ",
+            "Sửu",
+            "Tý",
+            "Tý",
+            "Mùi",
+            "Mùi",
+            "Thìn",
+            "Dần",
+            "Kỷ",
+            "Kỷ",
+            "Mùi",
+            "Tuất",
+            "Tỵ",
+            "Mão",
+            "Dần",
+            "Ngọ",
+            "Tý",
+            "Ngọ",
+            "Mùi",
+            "Tuất",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Mùi",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Ngọ",
+            "Giáp Dần",
+            "Canh Tuất",
+            "Tuất"
+            ),//9
+                new Array(
+            "Thân",
+            "Ngọ",
+            "Mão",
+            "Tỵ",
+            "Mão",
+            "Dần",
+            "Tỵ",
+            "Thân",
+            "Thân",
+            "Hợi",
+            "Sửu",
+            "Hợi",
+            "Thân",
+            "Dần Ngọ Tuất",
+            "Sửu",
+            "Thìn",
+            "Hợi",
+            "Thân",
+            "Sửu",
+            "Tuất",
+            "Ngọ",
+            "Hợi",
+            "Mão",
+            "Hợi",
+            "Dậu",
+            "Hợi",
+            "Thân",
+            "Dần",
+            "Mùi",
+            "Hợi",
+            "Nhâm",
+            "Nhâm",
+            "Dậu",
+            "Tý",
+            "Mão",
+            "Sửu",
+            "Hợi",
+            "Mùi",
+            "Sửu",
+            "Dậu",
+            "Hợi",
+            "Thìn",
+            "Tý",
+            "Canh Tý",
+            "Nhâm Tý",
+            "Dậu",
+            "Tý",
+            "Sửu",
+            "Dần",
+            "Nhâm Thìn",
+            "Thân",
+            "Tỵ",
+            "Tuất",
+            "Thân",
+            "Quý Sửu",
+            "Quý Hợi",
+            "Tuất"
+            ),//10
+                new Array(
+            "Mão",
+            "Mão",
+            "Ngọ",
+            "Dậu",
+            "Thìn",
+            "Mão",
+            "Ngọ Mùi",
+            "Tỵ",
+            "Dậu",
+            "Tý",
+            "Dần",
+            "Tý",
+            "Mão",
+            "Dần Ngọ Tuất",
+            "Ngọ",
+            "Mão",
+            "Ngọ",
+            "Mùi",
+            "Tý",
+            "Mùi",
+            "Dần",
+            "Mão",
+            "Sửu",
+            "Dậu",
+            "Ngọ",
+            "Mùi",
+            "Dậu",
+            "Dậu",
+            "Tuất",
+            "Thân",
+            "Quý",
+            "Quý",
+            "Hợi",
+            "Dần",
+            "Sửu",
+            "Mùi",
+            "Tỵ",
+            "Thân",
+            "Dần",
+            "Dần",
+            "Mão",
+            "Hợi",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Ngọ",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Dậu",
+            "Nhâm Tý",
+            "Nhâm Tý",
+            "Tuất"
+            ),//11
+                new Array(
+            "Tuất",
+            "Tý",
+            "Dậu",
+            "Sửu",
+            "Tỵ",
+            "Thìn",
+            "Mùi",
+            "Dần",
+            "Tuất",
+            "Sửu",
+            "Mão",
+            "Mão",
+            "Dậu",
+            "Dần Ngọ Tuất",
+            "Hợi",
+            "Dần",
+            "Tý",
+            "Ngọ",
+            "Hợi",
+            "Thìn",
+            "Tý",
+            "Mùi",
+            "Hợi",
+            "Mùi",
+            "Mão",
+            "Tuất",
+            "Thìn",
+            "Thìn",
+            "Sửu",
+            "Tỵ",
+            "Kỷ",
+            "Kỷ",
+            "Sửu",
+            "Thìn",
+            "Mùi",
+            "Dậu",
+            "Thân",
+            "Dậu",
+            "Mão",
+            "Thìn",
+            "Tuất",
+            "Tỵ",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Tuất",
+            "-",
+            "-",
+            "-",
+            "-",
+            "Sửu",
+            "Quý Hợi",
+            "Quý Sửu",
+            "Tuất"
+            )//12
         );
 
 function cacsaotot(lunarMonth, lunarDayCanChi){
@@ -1067,7 +1705,6 @@ function cacsaotot(lunarMonth, lunarDayCanChi){
 
     var SAOTOT="";
     var js=1;
-    var asf=1;
 
     for (var j=0;j<=48;j++){
 
@@ -1075,14 +1712,8 @@ function cacsaotot(lunarMonth, lunarDayCanChi){
             if (js==1){
               SAOTOT = SAO_TOT_TEN[j];
               js++;
-            }else{
-                if (asf%3==0)
-                   var rchar  = "<br>";
-                else
-                    var rchar = ", ";
-              SAOTOT += rchar+SAO_TOT_TEN[j];
-                asf++;
-            }
+            }else
+                SAOTOT += ", "+SAO_TOT_TEN[j];
     }
 
     return SAOTOT;
@@ -1128,7 +1759,6 @@ function cacsaoxau(lunarMonth, lunarDayCanChi){
 
     var SAOXAU="";
     var js=1;
-    var asf=1;
 
     for (var j=0;j<=48;j++){
 
@@ -1136,18 +1766,68 @@ function cacsaoxau(lunarMonth, lunarDayCanChi){
             if (js==1){
               SAOXAU = SAO_XAU_TEN[j];
               js++;
-            }else{
-                if (asf%3==0)
-                   var rchar  = "<br>";
-                else
-                    var rchar = ", ";
-              SAOXAU += rchar+SAO_XAU_TEN[j];
-                asf++;
-            }
+            }else
+                SAOXAU += ", "+SAO_XAU_TEN[j];
     }
 
     return SAOXAU;
 }
 
-function test(){
+function huong_xuat_hanh(lunarDayCanChi){
+    var CAN = lunarDayCanChi.split(" ")[0];
+    var hythan_huong="";
+    var taithan_huong="";
+    var hacthan_huong="";
+
+    if (CAN == "Giáp" || CAN == "Kỷ") hythan_huong = "Đông Bắc";else
+        if (CAN == "Ất" || CAN == "Canh") hythan_huong = "Tây Bắc";else
+            if (CAN == "Bính" || CAN == "Tân") hythan_huong = "Tây Nam";else
+                if (CAN == "Đinh" || CAN == "Nhâm") hythan_huong = "Nam";else
+                     hythan_huong = "Đông Nam";
+
+    if (CAN == "Giáp" || CAN == "Ất") taithan_huong = "Đông Nam";else
+        if (CAN == "Bính" || CAN == "Đinh") taithan_huong = "Đông";else
+            if (CAN == "Mậu") taithan_huong = "Bắc";else
+                if (CAN == "Kỷ") taithan_huong = "Nam";else
+                if (CAN == "Canh" || CAN == "Tân") taithan_huong = "Tây Nam";else
+                    if (CAN == "Nhâm") taithan_huong = "Tây";else
+                     taithan_huong = "Tây Bắc";
+
+    if (lunarDayCanChi == "Kỷ Dậu" || lunarDayCanChi == "Canh Tuất" || lunarDayCanChi == "Tân Hợi" || lunarDayCanChi == "Nhâm Tý"
+            || lunarDayCanChi == "Quý Sửu" || lunarDayCanChi == "Giáp Dần")
+        hacthan_huong = "Đông Bắc";
+    else
+        if (lunarDayCanChi == "Ất Mão" || lunarDayCanChi == "Bính Thìn" || lunarDayCanChi == "Đinh Tỵ" || lunarDayCanChi == "Mậu Ngọ"
+                || lunarDayCanChi == " Kỷ Mùi" )
+                    hacthan_huong = "Đông";
+    else
+            if (lunarDayCanChi == "Canh Thân" || lunarDayCanChi == "Tân Dậu" || lunarDayCanChi == "Nhâm Tuất" || lunarDayCanChi == "Quý Hợi"
+                    || lunarDayCanChi == "Giáp Tý" || lunarDayCanChi == "Ất Sửu" )
+                        hacthan_huong = "Đông Nam";
+            else
+                    if (lunarDayCanChi == "Bính Dần" || lunarDayCanChi == "Đinh Mão" || lunarDayCanChi == "Mậu Thìn" || lunarDayCanChi == "Kỷ Tỵ"
+                            || lunarDayCanChi == "Canh Ngọ" )
+                                hacthan_huong = "Nam";
+                    else
+                            if (lunarDayCanChi == "Tân Mùi" || lunarDayCanChi == "Nhâm Thân" || lunarDayCanChi == "Quý Dậu" || lunarDayCanChi == "Giáp Tuất"
+                                    || lunarDayCanChi == "Ất Hợi" || lunarDayCanChi == "Bính Tý" )
+                                        hacthan_huong = "Tây Nam";
+                            else
+                                    if (lunarDayCanChi == "Đinh Sửu" || lunarDayCanChi == "Mậu Dần" || lunarDayCanChi == "Kỷ Mão" || lunarDayCanChi == "Canh Thìn"
+                                            || lunarDayCanChi == "Tân Tỵ" )
+                                                hacthan_huong = "Tây";
+                                    else
+                                            if (lunarDayCanChi == "Nhâm Ngọ" || lunarDayCanChi == "Quý Mùi" || lunarDayCanChi == "Giáp Thân" || lunarDayCanChi == "Ất Dậu"
+                                                    || lunarDayCanChi == "Bính Tuất" || lunarDayCanChi == "Đinh Hợi")
+                                                        hacthan_huong = "Tây Bắc";
+                                            else
+                                                    if (lunarDayCanChi == "Mậu Tý" || lunarDayCanChi == "Kỷ Sửu" || lunarDayCanChi == "Canh Dần" || lunarDayCanChi == "Tân Mão"
+                                                            || lunarDayCanChi == "Nhâm Thìn")
+                                                                hacthan_huong = "Bắc";
+
+    var rfinal="&bull; Tài Thần: <b>"+taithan_huong+"</b><br>&bull; Hỷ Thần: <b>"+hythan_huong+"</b>";
+    if (hacthan_huong)
+        rfinal+="<br>&bull; Hạc Thần:<b>"+hacthan_huong+"</b>";
+
+    return rfinal;
 }
